<?php

/**
 * This file is part of the Froxlor project.
 * Copyright (c) 2010 the Froxlor Team (see authors).
 *
 * For the full copyright and license information, please view the COPYING
 * file that was distributed with this source code. You can also view the
 * COPYING file online at http://files.froxlor.org/misc/COPYING.txt
 *
 * @copyright  (c) the authors
 * @author     Froxlor team <team@froxlor.org> (2010-)
 * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
 * @package    System
 *
 */

// Main version variable
$version = \Froxlor\Froxlor::VERSION;

// Database version (YYYYMMDDC where C is a daily counter)
$dbversion = \Froxlor\Froxlor::DBVERSION;

// Distribution branding-tag (used for Debian etc.)
$branding = \Froxlor\Froxlor::BRANDING;
